@@ -3,7 +3,9 @@
 import os, shutil
 from unittest import TestCase
 from tg.appwrappers.caching import CacheApplicationWrapper
+from tg.appwrappers.errorpage import ErrorPageApplicationWrapper
 from tg.appwrappers.i18n import I18NApplicationWrapper
+from tg.appwrappers.identity import IdentityApplicationWrapper
 from tg.appwrappers.session import SessionApplicationWrapper
 
 try:
@@ -36,7 +38,7 @@ def setup_session_dir():
 def teardown_session_dir():
     shutil.rmtree(session_dir, ignore_errors=True)
 
-def make_app(controller_klass=None, environ=None, config_options=None):
+def make_app(controller_klass=None, environ=None, config_options=None, with_errors=False):
     """Creates a `TestApp` instance."""
     if controller_klass is None:
         controller_klass = TGController
@@ -47,9 +49,16 @@ def make_app(controller_klass=None, environ=None, config_options=None):
     config = default_config.copy()
     config['application_wrappers'] = [
         I18NApplicationWrapper,
+        IdentityApplicationWrapper,
         CacheApplicationWrapper,
         SessionApplicationWrapper
     ]
+
+    if with_errors:
+        config['errorpage.enabled'] = True
+        config['errorpage.status_codes'] = [403, 404]
+        config['application_wrappers'].append(ErrorPageApplicationWrapper)
+
     config['session.enabled'] = True
     config['session.data_dir'] = session_dir
     config['cache.enabled'] = True
@@ -65,37 +74,6 @@ def make_app(controller_klass=None, environ=None, config_options=None):
     app = RegistryManager(app)
     return TestApp(app)
 
-def create_request(path, environ=None):
-    """Helper used in test cases to quickly setup a request obj.
-
-    ``path``
-        The path will become PATH_INFO
-    ``environ``
-        Additional environment
-
-    Returns an instance of the `webob.Request` object.
-    """
-    # setup the environ
-    if environ is None:
-        environ = {}
-
-    # create a "blank" WebOb Request object
-    # using TG Request which is a webob Request plus
-    # some compatibility methods
-    req = request_local.Request.blank(path, environ)
-
-    # setup a Registry
-    reg = environ.setdefault('paste.registry', Registry())
-    reg.prepare()
-
-    # Setup turbogears context with request, url and tmpl_context
-    tgl = RequestLocals()
-    tgl.tmpl_context = TemplateContext()
-    tgl.request = req
-
-    request_local.context._push_object(tgl)
-
-    return req
 
 class TestWSGIController(TestCase):
     def setUp(self):
