@@ -5,6 +5,10 @@ from nose import SkipTest
 from nose.tools import eq_, raises
 import atexit, sys, os
 from datetime import datetime
+from sqlalchemy.orm import scoped_session
+from sqlalchemy.orm import sessionmaker
+from ming import Session
+from ming.orm import ThreadLocalORMSession
 from tg.configuration.hooks import _TGGlobalHooksNamespace
 
 from tg.appwrappers.errorpage import ErrorPageApplicationWrapper
@@ -13,7 +17,7 @@ from tg.appwrappers.transaction_manager import TransactionApplicationWrapper
 
 from tg.util import Bunch
 from tg.configuration import AppConfig, config
-from tg.configuration.app_config import TGConfigError
+from tg.configuration.app_config import TGConfigError, defaults as app_config_defaults
 from tg.configuration.auth import _AuthenticationForgerPlugin
 from tg.configuration.auth.metadata import _AuthMetadataAuthenticator
 from tg.configuration.utils import coerce_config, coerce_options
@@ -22,7 +26,7 @@ from tg.support.converters import asint, asbool
 
 import tg.i18n
 from tg import TGController, expose, response, request, abort
-from tests.base import TestWSGIController, make_app, setup_session_dir, teardown_session_dir, create_request
+from tests.base import setup_session_dir, teardown_session_dir
 from webtest import TestApp
 from tg.renderers.base import RendererFactory
 
@@ -187,9 +191,9 @@ class TestAppConfig:
 
     def test_get_root(self):
         current_root_module = self.config['paths']['root']
-        assert self.config.get_root_module() == 'tests.controllers.root', self.config.get_root_module()
+        assert self.config._get_root_module() == 'tests.controllers.root', self.config._get_root_module()
         self.config['paths']['root'] = None
-        assert self.config.get_root_module() == None, self.config.get_root_module()
+        assert self.config._get_root_module() == None, self.config._get_root_module()
         self.config['paths']['root'] = current_root_module
 
     def test_lang_can_be_changed_by_ini(self):
@@ -211,9 +215,80 @@ class TestAppConfig:
         #This is here to avoid that other tests keep using the forced controller
         config.pop('tg.root_controller')
 
-    def test_enable_routes(self):
-        if PY3: raise SkipTest()
+    def test_minimal_app_with_sqlalchemy(self):
+        class RootController(TGController):
+            @expose()
+            def test(self):
+                return 'HI!'
 
+        DBSession = scoped_session(sessionmaker(autoflush=True, autocommit=False))
+        def init_model(engine):
+            DBSession.configure(bind=engine)
+
+        conf = AppConfig(minimal=True, root_controller=RootController())
+
+        conf['use_sqlalchemy'] = True
+        conf['sqlalchemy.url'] = 'sqlite://'
+        conf['model'] = Bunch(DBSession=DBSession,
+                              init_model=init_model)
+
+        app = conf.make_wsgi_app()
+        app = TestApp(app)
+        assert 'HI!' in app.get('/test')
+
+    @raises(TGConfigError)
+    def test_sqlalchemy_without_models(self):
+        class RootController(TGController):
+            @expose()
+            def test(self):
+                return 'HI!'
+
+        conf = AppConfig(minimal=True, root_controller=RootController())
+        conf['use_sqlalchemy'] = True
+        conf['sqlalchemy.url'] = 'sqlite://'
+        app = conf.make_wsgi_app()
+
+    def test_minimal_app_with_ming(self):
+        class RootController(TGController):
+            @expose()
+            def test(self):
+                return 'HI!'
+
+        mainsession = Session()
+        DBSession = ThreadLocalORMSession(mainsession)
+
+        def init_model(engine):
+            mainsession.bind = engine
+
+        conf = AppConfig(minimal=True, root_controller=RootController())
+
+        conf['use_ming'] = True
+        conf['ming.url'] = 'mim://'
+        conf['model'] = Bunch(init_model=init_model, DBSession=DBSession)
+
+        app = conf.make_wsgi_app()
+        app = TestApp(app)
+        assert 'HI!' in app.get('/test')
+
+    @raises(TGConfigError)
+    def test_ming_without_models(self):
+        class RootController(TGController):
+            @expose()
+            def test(self):
+
+                return 'HI!'
+
+        DBSession = scoped_session(sessionmaker(autoflush=True, autocommit=False))
+        def init_model(engine):
+            DBSession.configure(bind=engine)
+
+        conf = AppConfig(minimal=True, root_controller=RootController())
+
+        conf['use_ming'] = True
+        conf['ming.url'] = 'mim://'
+        app = conf.make_wsgi_app()
+
+    def test_enable_routes(self):
         conf = AppConfig(minimal=True)
         conf.enable_routes = True
         app = conf.make_wsgi_app()
@@ -1962,8 +2037,8 @@ class TestAppConfig:
 
         conf = AppConfig(minimal=True, root_controller=RootController())
         conf.prefer_toscawidgets2 = True
-        conf.renderers = ['kajiki', 'genshi']
-        conf.default_renderer = 'kajiki'
+        conf.renderers = ['json', 'genshi']
+        conf.default_renderer = 'json'
 
         app = conf.make_wsgi_app(full_stack=True)
         app = TestApp(app)
@@ -2004,8 +2079,8 @@ class TestAppConfig:
 
         conf = AppConfig(minimal=True, root_controller=RootController())
         conf.prefer_toscawidgets2 = True
-        conf.renderers = ['kajiki']
-        conf.default_renderer = 'kajiki'
+        conf.renderers = ['json']
+        conf.default_renderer = 'json'
 
         try:
             app = conf.make_wsgi_app(full_stack=True)
@@ -2133,3 +2208,37 @@ class TestAppConfig:
 
         resp = app.get('/test', status=500)
         assert 'Exception: Crash! // Backlash' in resp, resp
+
+    def test_make_app_with_custom_appglobals(self):
+        class RootController(TGController):
+            @expose('')
+            def test(self, *args, **kwargs):
+                return tg.app_globals.TEXT
+
+        class FakeGlobals(Bunch):
+            def __init__(self):
+                super(FakeGlobals, self).__init__()
+                self['TEXT'] = 'HI!'
+
+        conf = AppConfig(minimal=True, root_controller=RootController())
+        conf.app_globals = FakeGlobals
+        app = conf.make_wsgi_app()
+        app = TestApp(app)
+        assert 'HI!' in app.get('/test')
+
+    def test_make_app_with_custom_helpers(self):
+        class RootController(TGController):
+            @expose('')
+            def test(self, *args, **kwargs):
+                return config['helpers'].get_text()
+
+        class FakeHelpers(Bunch):
+            @classmethod
+            def get_text(cls):
+                return 'HI!'
+
+        conf = AppConfig(minimal=True, root_controller=RootController())
+        conf.helpers = FakeHelpers()
+        app = conf.make_wsgi_app()
+        app = TestApp(app)
+        assert 'HI!' in app.get('/test')
\ No newline at end of file
