@@ -15,11 +15,9 @@ class TestConfig(AppConfig):
         if values is None:
             values = {}
         AppConfig.__init__(self)
-        #First we setup some base values that we know will work
-        self.renderers = ['genshi', 'mako', 'jinja','json', 'jsonp']
-        if not PY3:
-            self.renderers.extend(['kajiki'])
 
+        # First we setup some base values that we know will work
+        self.renderers = ['genshi', 'mako', 'jinja','json', 'jsonp', 'kajiki']
         self.render_functions = tg.util.Bunch()
         self.package = tests.test_stack
         self.default_renderer = 'genshi'
@@ -34,22 +32,18 @@ class TestConfig(AppConfig):
         root = os.path.dirname(os.path.dirname(tests.__file__))
         test_base_path = os.path.join(root,'tests', 'test_stack',)
         test_config_path = os.path.join(test_base_path, folder)
-        self.paths=tg.util.Bunch(
-                    root=test_base_path,
-                    controllers=os.path.join(test_config_path, 'controllers'),
-                    static_files=os.path.join(test_config_path, 'public'),
-                    templates=[os.path.join(test_config_path, 'templates')],
-                    i18n=os.path.join(test_config_path, 'i18n')
-                    )
+        self.paths = tg.util.Bunch(
+            root=test_base_path,
+            controllers=os.path.join(test_config_path, 'controllers'),
+            static_files=os.path.join(test_config_path, 'public'),
+            templates=[os.path.join(test_config_path, 'templates')],
+            i18n=os.path.join(test_config_path, 'i18n')
+        )
+
         # then we override those values with what was passed in
         for key, value in values.items():
             setattr(self, key, value)
 
-    def setup_helpers_and_globals(self):
-        tg.config['tg.app_globals'] = self.globals
-        g = tg.config['tg.app_globals']
-        g.dotted_filename_finder = DottedFileNameFinder()
-
     def add_debugger_middleware(self, global_conf, app):
         return app
 
