@@ -123,13 +123,13 @@ class RootController(TGController):
 
     @expose()
     def flash_redirect(self):
-        tg.flash("Wow, flash!")
+        tg.flash("Wow, <br/>flash!")
         tg.redirect("/flash_after_redirect")
 
     @expose()
     def flash_render(self, using_js=False, with_message=True):
         if asbool(with_message):
-            tg.flash('JS Flash')
+            tg.flash('JS <br/>Flash')
 
         return tg.flash.render('flash', asbool(using_js))
 
@@ -232,6 +232,11 @@ class RootController(TGController):
     def without_tslash(self):
         return 'HI'
 
+    @expose()
+    @with_engine('mainslave')
+    def onmaster_without_params(self, **kw):
+        return '%s-%s' % (tg.request._tg_force_sqla_engine, kw)
+
     @expose()
     @with_engine('mainslave', master_params=['first'])
     def onmaster_withlist(self, **kw):
