@@ -55,14 +55,31 @@ def test_default_chameleon_genshi_renderer():
     assert "TurboGears" in resp, resp
 
 def test_default_kajiki_renderer():
-    if PY3: raise SkipTest()
-    if '__pypy__' in sys.builtin_module_names: raise SkipTest()
-
     app = setup_noDB()
     resp = app.get('/kajiki_index_dotted')
     assert "Welcome" in resp, resp
     assert "TurboGears" in resp, resp
 
+def test_kajiki_i18n():
+    app = setup_noDB()
+    resp = app.get('/kajiki_i18n')
+    assert u_("Your application is now running") in resp
+
+def test_kajiki_i18n_de():
+    app = setup_noDB()
+    resp = app.get('/kajiki_i18n_de')
+    assert u_("Ihre Anwendung läuft jetzt einwandfrei") in resp
+
+def test_kajiki_missing_template():
+    app = setup_noDB()
+
+    try:
+        resp = app.get('/kajiki_missing_template')
+    except IOError as e:
+        assert 'missing.xhtml not found' in str(e)
+    else:
+        assert False, 'Should have raised IOError'
+
 def test_jinja_dotted():
     app = setup_noDB()
     resp = app.get('/jinja_dotted')
@@ -128,4 +145,3 @@ def test_mako_inheritance():
     resp = app.get('/mako_inherits_dotted')
     assert "inherited mako page" in resp, resp
     assert "Inside parent template" in resp, resp
-
