@@ -6,7 +6,7 @@ from crank.util import get_params_with_argspec
 
 import tg
 import tests
-from json import loads, dumps
+from json import loads
 import datetime
 
 from tg.controllers import TGController, DecoratedController, abort
@@ -16,8 +16,8 @@ from tests.base import (TestWSGIController, data_dir,
     make_app, setup_session_dir, teardown_session_dir)
 
 from tg._compat import PY3, unicode_text, u_, default_im_func
-from tg.validation import TGValidationError, validation_errors
-
+from tg.validation import TGValidationError, validation_errors, _ValidationStatus, Convert
+from tg.i18n import lazy_ugettext as l_
 from formencode import validators, Schema
 
 import tw2.core as tw2c
@@ -60,8 +60,8 @@ def setup():
 def teardown():
     teardown_session_dir()
 
-class controller_based_validate(validate):
 
+class controller_based_validate(validate):
     def __init__(self, error_handler=None, *args, **kw):
         self.error_handler = error_handler
         self.needs_controller = True
@@ -80,6 +80,11 @@ class ColonLessGenericValidator(object):
     def validate(self, value, state=None):
         raise validators.Invalid('Unknown Error', value, {'_the_form':'Unknown Error'})
 
+class ThrowAwayValidationIntentValidator(object):
+    def validate(self, value, state=None):
+        tg.request.validation.intent = None
+        raise validators.Invalid('Unknown Error', value, {'_the_form':'Unknown Error'})
+
 def error_handler_function(controller_instance, uid, num):
     return 'UID: %s' % uid
 
@@ -172,9 +177,9 @@ class BasicTGController(TGController):
         kwargs['errors'] = tg.request.validation['errors']
         return dict(kwargs)
 
-    @expose()
+    @expose('json')
     def tw2form_error_handler(self, **kwargs):
-        return dumps(dict(errors=tg.request.validation['errors']))
+        return dict(errors=tg.request.validation['errors'])
 
     @expose('json:')
     @validate(form=movie_form, error_handler=tw2form_error_handler)
@@ -182,9 +187,16 @@ class BasicTGController(TGController):
         return 'passed validation'
 
     @expose()
-    @validate({'param':tw2c.IntValidator()})
+    @validate({'param': tw2c.IntValidator()},
+              error_handler=validation_errors_response)
     def tw2_dict_validation(self, **kwargs):
-        return str(tg.request.validation['errors'])
+        return 'NO_ERROR'
+
+    @expose()
+    @validate({'param': validators.Int()},
+              error_handler=validation_errors_response)
+    def formencode_dict_validation(self, **kwargs):
+        return 'NO_ERROR'
 
     @expose('text/plain')
     @validate(form=FormWithFieldSet, error_handler=tw2form_error_handler)
@@ -262,6 +274,14 @@ class BasicTGController(TGController):
     def validate_callable(self, uid, num):
         return 'HUH'
 
+    @expose()
+    @validate({'uid': validators.Int()},
+              error_handler=ErrorHandlerCallable())
+    @validate({'num': validators.Int()},
+              error_handler=abort(412, error_handler=True))
+    def validate_multi(self, uid, num):
+        return str(uid+num)
+
     @expose()
     @validate({'uid': validators.Int()},
               error_handler=abort(412, error_handler=True))
@@ -276,7 +296,7 @@ class BasicTGController(TGController):
 
     @expose()
     def validate_json_errors_complex_types(self, date):
-        tg.request.validation['values'] = {'date': datetime.datetime.utcnow()}
+        tg.request.validation.values = {'date': datetime.datetime.utcnow()}
         return validation_errors_response()
 
     @expose()
@@ -284,6 +304,19 @@ class BasicTGController(TGController):
     def hooked_error_handler(self, uid, num):
         return 'UID: %s, NUM: %s' % (uid, num)
 
+    @expose()
+    @validate(ThrowAwayValidationIntentValidator(),
+              error_handler=abort(412, error_handler=True))
+    def throw_away_intent(self, uid):
+        if tg.request.validation.exception:
+            return 'ERROR'
+        return 'UHU?'
+
+    @expose()
+    @validate(error_handler=hooked_error_handler)
+    def passthrough_validation(self, uid):
+        return str(uid)
+
     @expose()
     @validate({'uid': validators.Int()},
               error_handler=hooked_error_handler)
@@ -314,6 +347,21 @@ class BasicTGController(TGController):
         return output
 
 
+    @expose(content_type='text/plain')
+    @validate({
+        'num': Convert(int, l_('This must be a number'))
+    }, error_handler=validation_errors_response)
+    def post_pow2(self, num=-1):
+        return str(num*num)
+
+    @expose(content_type='text/plain')
+    @validate({
+        'num': Convert(int, l_('This must be a number'), default=0)
+    }, error_handler=validation_errors_response)
+    def post_pow2_opt(self, num=-1):
+        return str(num*num)
+
+
 class TestTGController(TestWSGIController):
     def setUp(self):
         TestWSGIController.setUp(self)
@@ -432,11 +480,18 @@ class TestTGController(TestWSGIController):
 
     def test_tw2dict_validation(self):
         resp = self.app.post('/tw2_dict_validation', {'param': "7"})
-        assert '{}' in str(resp.body)
+        assert 'NO_ERROR' in str(resp.body)
 
-        resp = self.app.post('/tw2_dict_validation', {'param': "hello"})
+        resp = self.app.post('/tw2_dict_validation', {'param': "hello"}, status=412)
         assert 'Must be an integer' in str(resp.body)
 
+    def test_formencode_dict_validation(self):
+        resp = self.app.post('/formencode_dict_validation', {'param': "7"})
+        assert 'NO_ERROR' in str(resp.body), resp
+
+        resp = self.app.post('/formencode_dict_validation', {'param': "hello"}, status=412)
+        assert 'Please enter an integer value' in str(resp.body), resp
+
     def test_form_validation_translation(self):
         if PY3: raise SkipTest()
 
@@ -515,6 +570,19 @@ class TestTGController(TestWSGIController):
                                                     'num': 'NaN'})
         assert resp.text == 'UID: 2', resp
 
+    def test_validate_multi(self):
+        resp = self.app.post('/validate_multi', {'uid': 'NaN', 'num': 2})
+        assert resp.text == 'UID: NaN', resp
+
+        resp = self.app.post('/validate_multi', {'uid': 2, 'num': 'NaN'}, status=412)
+        assert resp.status.startswith('412')
+
+        resp = self.app.post('/validate_multi', {'uid': 2, 'num': 2})
+        assert resp.text == '4', resp
+
+        resp = self.app.post('/validate_multi', {'uid': 'NaN', 'num': 'NaN'})
+        assert resp.text == 'UID: NaN', resp
+
     def test_validate_hooked(self):
         resp = self.app.post('/validate_hooked', {'uid': 'NaN'})
         assert resp.text == 'UID: NaN, NUM: 5X', resp
@@ -538,3 +606,64 @@ class TestTGController(TestWSGIController):
                              status=412)
         assert resp.json['values']['date'] == '2014-01-01', resp
 
+    def test_throw_way_validation_intent(self):
+        # This should actually never happen.
+        # It requires the validator to mess up with TG internals, it's just to provide full coverage.
+        resp = self.app.post('/throw_away_intent', {'uid': 5})
+        assert resp.text == 'ERROR', resp
+
+    def test_passthrough_validation(self):
+        # This should actually never happen.
+        # It requires the validator to mess up with TG internals, it's just to provide full coverage.
+        resp = self.app.post('/passthrough_validation', {'uid': 5})
+        assert resp.text == '5', resp
+
+    def test_ValidationStatus_asdict(self):
+        vs = _ValidationStatus()
+        assert vs['errors'] is vs.errors
+        assert vs['values'] is vs.values
+        assert vs['error_handler'] is vs.error_handler
+
+        try:
+            vs['this_does_not_exists']
+        except KeyError:
+            pass
+        else:
+            assert False, 'Should have raised KeyError'
+
+    def test_backward_compatibility_decorator(self):
+        deco = Decoration.get_decoration(BasicTGController.two_validators)
+
+        validated_params = sorted(list(deco.validation.validators.keys()))
+        assert validated_params == ["a", "someemail"], validated_params
+
+        deco = Decoration.get_decoration(BasicTGController.tw2form_error_handler)
+        assert deco.validation is None, deco.validation
+
+    def test_convert_validation(self):
+        resp = self.app.post('/post_pow2', {'num': '5'})
+        assert resp.text == '25', resp
+
+    def test_convert_validation_fail(self):
+        resp = self.app.post('/post_pow2', {'num': 'HELLO'}, status=412)
+        assert 'This must be a number' in resp.text, resp
+
+    def test_convert_validation_missing(self):
+        resp = self.app.post('/post_pow2', {'num': ''}, status=412)
+        assert 'This must be a number' in resp.text, resp
+
+        resp = self.app.post('/post_pow2', status=412)
+        assert 'This must be a number' in resp.text, resp
+
+    def test_convert_validation_optional(self):
+        resp = self.app.post('/post_pow2_opt', {'num': 'HELLO'}, status=412)
+        assert 'This must be a number' in resp.text, resp
+
+        resp = self.app.post('/post_pow2_opt', {'num': '5'})
+        assert resp.text == '25', resp
+
+        resp = self.app.post('/post_pow2_opt', {'num': ''})
+        assert resp.text == '0', resp
+
+        resp = self.app.post('/post_pow2_opt')
+        assert resp.text == '0', resp
