@@ -52,24 +52,28 @@ assumptions about how things will work.
 
 """
 
-from pylons import app_globals, request, response, tmpl_context, session, cache, translator
-
+from tg.request_local import app_globals, request, response, tmpl_context, session, cache, translator
+from tg.configuration import config, AppConfig
 from tg.wsgiapp import TGApp
-from tg.controllers import TGController, redirect, url, lurl, abort
-from tg.configuration import config
+from tg.controllers import TGController, RestController, redirect, url, lurl, abort
 from tg.release import version
 from tg.decorators import (validate, expose, override_template, use_custom_format,
-                           require, allow_only)
+                           require, with_engine, cached, decode_params)
 
 from tg.flash import flash, get_flash, get_status
 from tg.jsonify import encode as json_encode
-from tg.controllers.util import use_wsgi_app
+from tg.controllers.util import *
 from tg.controllers.dispatcher import dispatched_controller
+from tg.render import render as render_template
+from tg.configuration.hooks import hooks
+
+from tg.request_local import Request, Response
 
 __version__ = version
 
 __all__ = ['__version__',
-    'allow_only', 'app_globals', 'expose', 'override_template', 'request',
+    'app_globals', 'expose', 'override_template', 'request',
     'require', 'response', 'session', 'TGApp', 'TGController', 'tmpl_context',
     'use_wsgi_app', 'validate', 'i18n','json_encode', 'cache', 'url', 'lurl',
-    'dispatched_controller', 'use_custom_format']
+    'dispatched_controller', 'use_custom_format', 'with_engine', 'render_template',
+    'Request', 'Response', 'cached', 'decode_params']
