@@ -6,6 +6,7 @@ import warnings
 from copy import copy, deepcopy
 import mimetypes
 from collections import MutableMapping as DictMixin, deque
+from tg.appwrappers.identity import IdentityApplicationWrapper
 
 from tg.support.middlewares import StaticsMiddleware, SeekableRequestBodyMiddleware, \
     DBSessionRemoverMiddleware
@@ -160,7 +161,63 @@ class AppConfig(Bunch):
     This is the place to configure custom routes, transaction handling,
     error handling, etc.
 
+    Configuration Options provided:
+
+        - ``debug`` -> Enables / Disables debug mode. **Can be set from .ini file**
+        - ``serve_static`` -> Enable / Disable serving static files. **Can be set from .ini file**
+        - ``use_dotted_templatenames`` -> Use template names as packages in @expose instead of file paths.
+          This is usually the default unless TG is started in Minimal Mode. **Can be set from .ini file**
+        - ``registry_streaming`` -> Enable streaming of responses, this is enabled by default.
+          **Can be set from .ini file**
+        - ``paths`` -> Dictionary of directories where templates, static files and controllers are found::
+
+            {
+                'controllers': 'my/path/to/controlllers',
+                'static_files': 'my/path/to/files',
+                'templates': ['list/of/paths/to/templates']
+            )
+        - ``use_toscawidgets`` -> Enable ToscaWidgets1, this is deprecated.
+        - ``use_toscawidgets2`` -> Enable ToscaWidgets2
+        - ``prefer_toscawidgets2`` -> When both TW2 and TW1 are enabled prefer TW2. **Can be set from .ini file**
+        - ``custom_tw2_config`` -> Dictionary of configuration options for TW2, refer to
+          :class:`.tw2.core.middleware.Config` for available options.
+        - ``auth_backend`` -> Authentication Backend, can be ``None``, ``sqlalchemy`` or ``ming``.
+        - ``sa_auth`` -> Simple Authentication configuration dictionary.
+          This is a Dictionary that contains the configuration options for ``repoze.who``,
+          see :ref:`authentication` for available options. Basic options include:
+
+            - ``cookie_secret`` -> Secret phrase used to verify auth cookies.
+            - ``authmetadata`` -> Authentication and User Metadata Provider for TurboGears
+            - ``post_login_url`` -> Redirect users here after login
+            - ``post_logout_url`` -> Redirect users here when they logout
+        - ``package`` -> Application Package, this is used to configure paths as being inside a python
+        - ``app_globals`` -> Application Globals class, by default build from ``package.lib.app_globals``.
+          package. Which enables serving templates, controllers, app globals and so on from the package itself.
+        - ``helpers`` -> Template Helpers, by default ``package.lib.helpers`` is used.
+        - ``model`` -> The models module (or object) where all the models, DBSession and init_models method are
+           available. By default ``package.model`` is used.
+        - ``renderers`` -> List of enabled renderers names.
+        - ``default_renderer`` -> When not specified, use this renderer for templates.
+        - ``auto_reload_templates`` -> Automatically reload templates when modified (disable this on production
+          for a performance gain). **Can be set from .ini file**
+        - ``use_ming`` -> Enable/Disable Ming as Models storage.
+        - ``ming.url`` -> Url of the MongoDB database
+        - ``ming.db`` -> If Database is not provided in ``ming.url`` it can be specified here.
+        - ``ming.connection.*`` -> Options to configure the ming connection,
+          refer to :func:`ming.datastore.create_datastore` for available options.
+        - ``use_sqlalchemy`` -> Enable/Disable Ming as Models storage.
+        - ``sqlalchemy.url`` -> Url of the SQLAlchemy database. Refer to :ref:`sqla_master_slave` for
+          configuring master-slave urls.
     """
+    CONFIG_OPTIONS = {
+        'debug': asbool,
+        'serve_static': asbool,
+        'auto_reload_templates': asbool,
+        'use_dotted_templatenames': asbool,
+        'registry_streaming': asbool,
+        'use_toscawidgets2': asbool,
+        'prefer_toscawidgets2': asbool
+    }
 
     def __init__(self, minimal=False, root_controller=None):
         """Creates some configuration defaults"""
@@ -169,15 +226,15 @@ class AppConfig(Bunch):
         self.paths = Bunch()
 
         # Provide a default app_globals for single file applications
-        self['tg.app_globals'] = Bunch({'dotted_filename_finder':DottedFileNameFinder()})
+        self.app_globals = None
+        self.helpers = None
 
         # And also very often...
         self.sa_auth = Bunch()
 
-        #Set individual defaults
+        # Set individual defaults
         self.auto_reload_templates = True
         self.auth_backend = None
-        self.stand_alone = True
         self.serve_static = not minimal
 
         self.renderers = []
@@ -235,13 +292,14 @@ class AppConfig(Bunch):
         self.register_rendering_engine(KajikiRenderer)
 
         self.register_wrapper(I18NApplicationWrapper, after=True)
+        self.register_wrapper(IdentityApplicationWrapper, after=True)
         self.register_wrapper(SessionApplicationWrapper, after=True)
         self.register_wrapper(CacheApplicationWrapper, after=True)
         self.register_wrapper(MingApplicationWrapper, after=True)
         self.register_wrapper(TransactionApplicationWrapper, after=True)
         self.register_wrapper(ErrorPageApplicationWrapper, after=True)
 
-    def get_root_module(self):
+    def _get_root_module(self):
         root_module_path = self.paths['root']
         if not root_module_path:
             return None
@@ -396,11 +454,7 @@ class AppConfig(Bunch):
         # Coerce some options that are bool
         conf.update(coerce_options(
             conf,
-            {
-                'debug': asbool,
-                'serve_static': asbool,
-                'auto_reload_templates': asbool
-            }
+            self.CONFIG_OPTIONS
         ))
 
         # Load the errorware configuration from the Paste configuration file
@@ -465,7 +519,7 @@ class AppConfig(Bunch):
         if not conf['paths']['static_files']:
             conf['serve_static'] = False
 
-        conf['application_root_module'] = self.get_root_module()
+        conf['application_root_module'] = self._get_root_module()
         if conf['paths']['root']:
             conf['localedir'] = os.path.join(conf['paths']['root'], 'i18n')
         else:
@@ -652,16 +706,19 @@ class AppConfig(Bunch):
     def setup_helpers_and_globals(self):
         """Add helpers and globals objects to the config.
 
-        Override this method to customize the way that ``app_globals``
-        and ``helpers`` are setup.
-
+        Override this method to customize the way that ``app_globals`` and ``helpers``
+        are setup.
         """
 
-        try:
-            g = self.package.lib.app_globals.Globals()
-        except AttributeError:
-            log.warn('Application has a package but no lib.app_globals.Globals class is available.')
-            return
+        gclass = getattr(self, 'app_globals', None)
+        if gclass is None:
+            try:
+                g = self.package.lib.app_globals.Globals()
+            except AttributeError:
+                log.warn('app_globals not provided and lib.app_globals.Globals class is not available.')
+                g = Bunch()
+        else:
+            g = gclass()
 
         g.dotted_filename_finder = DottedFileNameFinder()
         config['tg.app_globals'] = g
@@ -669,6 +726,15 @@ class AppConfig(Bunch):
         if config.get('tg.pylons_compatible', True):
             config['pylons.app_globals'] = g
 
+        h = getattr(self, 'helpers', None)
+        if h is None:
+            try:
+                h = self.package.lib.helpers
+            except AttributeError:
+                log.warn('helpers not provided and lib.helpers is not available.')
+                h = Bunch()
+        config['helpers'] = h
+
     def setup_persistence(self):
         """Override this method to define how your application configures it's persistence model.
            the default is to setup sqlalchemy from the cofiguration file, but you might choose
@@ -719,7 +785,22 @@ class AppConfig(Bunch):
         datastore = create_ming_datastore(config['ming.url'], config.get('ming.db', ''),
                                           **datastore_options)
         config['tg.app_globals'].ming_datastore = datastore
-        self.package.model.init_model(datastore)
+
+        try:
+            package_models = self.package.model
+        except AttributeError:
+            package_models = None
+
+        model = getattr(self, 'model', package_models)
+        if model is None:
+            raise TGConfigError('Ming enabled, but no models provided')
+
+        model.init_model(datastore)
+
+        if not hasattr(self, 'DBSession'):
+            # If the user hasn't specified a session, assume
+            # he/she uses the default DBSession in model
+            self.DBSession = model.DBSession
 
     def setup_sqlalchemy(self):
         """Setup SQLAlchemy database engine.
@@ -780,12 +861,21 @@ class AppConfig(Bunch):
 
         # Pass the engine to initmodel, to be able to introspect tables
         config['tg.app_globals'].sa_engine = engine
-        self.package.model.init_model(engine)
+
+        try:
+            package_models = self.package.model
+        except AttributeError:
+            package_models = None
+
+        model = getattr(self, 'model', package_models)
+        if model is None:
+            raise TGConfigError('SQLAlchemy enabled, but no models provided')
+
+        model.init_model(engine)
 
         if not hasattr(self, 'DBSession'):
             # If the user hasn't specified a scoped_session, assume
             # he/she uses the default DBSession in model
-            model = getattr(self, 'model', self.package.model)
             self.DBSession = model.DBSession
 
     def setup_auth(self):
@@ -873,16 +963,7 @@ class AppConfig(Bunch):
             tg.hooks.notify('startup', trap_exceptions=True)
 
             self.setup_routes()
-
-            try:
-                self.package
-            except AttributeError:
-                # if we don't have a specified package, don't try
-                # helpers from the package expect the user to specify them.
-                log.debug('Helpers not configured due to missing application package')
-            else:
-                self.setup_helpers_and_globals()
-
+            self.setup_helpers_and_globals()
             self.setup_auth()
             self._setup_renderers()
             self.setup_persistence()
@@ -951,7 +1032,11 @@ class AppConfig(Bunch):
                                 "you must define it in app_cfg.py or set "
                                 "sa_auth.cookie_secret in development.ini")
 
-        if 'authmetadata' not in auth_args: #pragma: no cover
+        if 'authmetadata' not in auth_args:  # pragma: no cover
+            warnings.warn("Authentication configured without authmetadata, "
+                          "this is not supported anymore and will be removed in future versions",
+                          DeprecationWarning)
+
             # authmetadata not provided, fallback to old authentication setup
             if self.auth_backend == "sqlalchemy":
                 from repoze.what.plugins.quickstart import setup_sql_auth
@@ -960,6 +1045,9 @@ class AppConfig(Bunch):
                 from tgming import setup_ming_auth
                 app = setup_ming_auth(app, skip_authentication=skip_authentication, **auth_args)
         else:
+            # Removing authmetadata as is not used by repoze.who:
+            tgauthmetadata = auth_args.pop('authmetadata', None)
+
             try:
                 pos = auth_args['authenticators'].index(('default', None))
             except KeyError:
@@ -971,9 +1059,9 @@ class AppConfig(Bunch):
                 pos = -1
 
             if pos is None or pos >= 0:
-                if getattr(auth_args['authmetadata'], 'authenticate', None) is not None:
+                if getattr(tgauthmetadata, 'authenticate', None) is not None:
                     from tg.configuration.auth import create_default_authenticator
-                    auth_args, tgauth = create_default_authenticator(**auth_args)
+                    auth_args, tgauth = create_default_authenticator(tgauthmetadata, **auth_args)
                     authenticator = ('tgappauth', tgauth)
                 elif self.auth_backend == "sqlalchemy":
                     from tg.configuration.sqla.auth import create_default_authenticator
@@ -1015,14 +1103,18 @@ class AppConfig(Bunch):
             warnings.warn('SessionMiddleware is deprecated and will be removed soon, '
                           'please consider using SessionApplicationWrapper instead.',
                           DeprecationWarning)
-            from tg.support.middlewares import SessionMiddleware
+            from tg.support.middlewares import SessionMiddleware, BeakerSessionMiddleware
+            if BeakerSessionMiddleware is object:  # pragma: no cover
+                raise ImportError('Beaker not installed')
             app = SessionMiddleware(app, config)
 
         if getattr(self, 'use_cache_middleware', False):
             warnings.warn('CacheMiddleware is deprecated and will be removed soon, '
                           'please consider using CacheApplicationWrapper instead.',
                           DeprecationWarning)
-            from tg.support.middlewares import CacheMiddleware
+            from tg.support.middlewares import CacheMiddleware, BeakerCacheMiddleware
+            if BeakerCacheMiddleware is object:  # pragma: no cover
+                raise ImportError('Beaker not installed')
             app = CacheMiddleware(app, config)
 
         return app
@@ -1139,8 +1231,9 @@ class AppConfig(Bunch):
                                         'mako': ['mak', 'mako'],
                                         'genshi': ['genshi', 'html'],
                                         'jinja':['jinja', 'jinja2'],
-                                        'kajiki':['kajiki', 'xml']
+                                        'kajiki':['kajiki', 'xhtml', 'xml']
                                    })
+
         default_tw2_config.update(self.custom_tw2_config)
         app = TwMiddleware(app, **default_tw2_config)
         return app
