@@ -1,7 +1,6 @@
 # -*- coding: utf-8 -*-
 """This module contains the main WSGI controller implementation."""
-
-import pylons
+import tg
 
 from tg.decorators import expose
 
@@ -16,10 +15,8 @@ class WSGIAppController(TGController):
     def __init__(self, app, allow_only=None):
         self.app = app
         self.allow_only = allow_only
-        # Signal tg.configuration.maybe_make_body_seekable which is wrapping
-        # The stack to make the body seekable so default() can rewind it.
-        pylons.configuration.config['make_body_seekable'] = True
-        # Calling the parent's constructor, to enable controller-wide auth:
+
+        # Calling the parent's contructor, to enable controller-wide auth:
         super(WSGIAppController, self).__init__()
 
     @expose()
@@ -31,25 +28,31 @@ class WSGIAppController(TGController):
         WSGI app.
 
         """
+        body_is_seekable = tg.config.get('make_body_seekable', False)
+        if not body_is_seekable:
+            raise RuntimeError('Mounting nested WSGI apps requires make_body_seekable=True option')
+
         # Push into SCRIPT_NAME the path components that have been consumed,
-        request = pylons.request._current_obj()
+        request = tg.request._current_obj()
         new_req = request.copy()
         to_pop = len(new_req.path_info.strip('/').split('/')) - len(args)
-        for i in xrange(to_pop):
+        for i in range(to_pop):
             new_req.path_info_pop()
-        if not new_req.path_info:
-            # Append trailing slash and redirect
-            redirect(request.path_info + '/')
-        new_req.body_file.seek(0)
-        return self.delegate(new_req.environ, request.start_response)
 
-    def delegate(self, environ, start_response):
+        if not new_req.path_info: #pragma: no cover
+            # This should not happen
+            redirect(request.path_info + '/')
+
+        new_req.body_file.seek(0)
+        return self.delegate(new_req)
+
+    def delegate(self, request):
         """Delegate the request to the WSGI app.
 
         Override me if you need to update the environ, mangle response, etc...
 
         """
-        return self.app(environ, start_response)
+        return request.get_response(self.app)
 
 
 __all__ = ['WSGIAppController']
